@@ -1,22 +1,22 @@
 /* Jitter: custom contextual printing.
 
-   Copyright (C) 2020 Luca Saiu
+   Copyright (C) 2020, 2022 Luca Saiu
    Written by Luca Saiu
 
-   This file is part of Jitter.
+   This file is part of GNU Jitter.
 
-   Jitter is free software: you can redistribute it and/or modify
+   GNU Jitter is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
-   Jitter is distributed in the hope that it will be useful,
+   GNU Jitter is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with Jitter.  If not, see <http://www.gnu.org/licenses/>. */
+   along with GNU Jitter.  If not, see <https://www.gnu.org/licenses/>. */
 
 
 #ifndef JITTER_PRINT_H_
@@ -90,8 +90,9 @@
    subject to failure. */
 
 
-/* A print context is a pointer to an opaque structure. */
-typedef struct jitter_print_context_private *
+/* A print context is a pointer to a struct that can usually be treated as
+   opaque. */
+typedef struct jitter_print_context_struct *
 jitter_print_context;
 
 
@@ -714,4 +715,26 @@ struct jitter_print_context_kind_struct
 void
 jitter_print_initialize (void);
 
+
+
+
+/* Internal functionality: struct definitions.
+ * ************************************************************************** */
+
+/* What a context consists of in memory.  This type can be treated as opaque by
+   the final user, and even by users defining new context kinds. */
+struct jitter_print_context_struct
+{
+  /* The stack of currently active decorations, the most current on the top.
+     The stack is empty at initialisation.  Items are all of type
+     struct jitter_print_decoration. */
+  struct jitter_dynamic_buffer stack;
+
+  /* The context kind.  This is a pointer. */
+  jitter_print_context_kind kind;
+
+  /* The context data, as appropriate for its kind.  This is a pointer. */
+  jitter_print_context_data data;
+};
+
 #endif // #ifndef JITTER_PRINT_H_
