@@ -1,6 +1,6 @@
 /* pkl-diag.h - Functions to emit compiler diagnostics.  */
 
-/* Copyright (C) 2020, 2021, 2022 Jose E. Marchesi */
+/* Copyright (C) 2020, 2021, 2022, 2023 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <stdarg.h>
 
 #include "pkl-ast.h"
+#include "pkl-parser.h"
 
 void pkl_error (pkl_compiler compiler, pkl_ast ast, pkl_ast_loc loc,
                 const char *fmt, ...);
@@ -33,4 +34,15 @@ void pkl_warning (pkl_compiler compiler, pkl_ast ast,
 void pkl_ice (pkl_compiler compiler, pkl_ast ast, pkl_ast_loc loc,
               const char *fmt, ...);
 
+
+/* Given a PKL parser and a location, allocate and return a
+   NULL-terminated string with the source code corresponding to the
+   location.
+
+   MAX_CHARS determines the maximum number of characters to allocate
+   in the string.  */
+
+char *pkl_loc_to_source (struct pkl_parser *parser, pkl_ast_loc loc,
+                         size_t max_chars);
+
 #endif /* ! PKL_DIAG_H */
