@@ -1,6 +1,6 @@
 /* pkl-gen.h - Code generation pass for the poke compiler.  */
 
-/* Copyright (C) 2019, 2020, 2021 Jose E. Marchesi */
+/* Copyright (C) 2019, 2020, 2021, 2022, 2023 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 
 /* It would be very unlikely to have more than 24 declarations nested
    in a poke program... if it ever happens, we will just increase
-   this, thats a promise :P (don't worry, there is an assertion that
+   this, that's a promise :P (don't worry, there is an assertion that
    will fire if this limit is surpassed.) */
 
 #define PKL_GEN_MAX_PASM 25
@@ -64,7 +64,7 @@
    to be used.
 
    CONTEXT is an array implementing a stack of contexts.  Each context
-   is a bitmap.  See hte PKL_GEN_CTX_* constants below for the
+   is a bitmap.  See the PKL_GEN_CTX_* constants below for the
    significance of each bit.  The initial context is initialized to 0.
 
    CUR_CONTEXT is the index to CONTEXT and marks the top of the stack
@@ -91,6 +91,7 @@ struct pkl_gen_payload
   int constructor_depth;
   int mapper_depth;
   int in_file_p;
+  pkl_env env;
 };
 
 typedef struct pkl_gen_payload *pkl_gen_payload;
@@ -111,14 +112,20 @@ typedef struct pkl_gen_payload *pkl_gen_payload;
 #define PKL_GEN_CTX_IN_ARRAY_BOUNDER 0x80
 #define PKL_GEN_CTX_IN_FUNCALL      0x200
 #define PKL_GEN_CTX_IN_TYPE         0x400
+#define PKL_GEN_CTX_IN_FORMATER     0x800
+#define PKL_GEN_CTX_IN_INTEGRATOR   0x1000
+#define PKL_GEN_CTX_IN_DEINTEGRATOR 0x2000
+#define PKL_GEN_CTX_IN_TYPIFIER     0x4000
 
 extern struct pkl_phase pkl_phase_gen;
 
 static inline void
-pkl_gen_init_payload (pkl_gen_payload payload, pkl_compiler compiler)
+pkl_gen_init_payload (pkl_gen_payload payload, pkl_compiler compiler,
+                      pkl_env env)
 {
   memset (payload, 0, sizeof (struct pkl_gen_payload));
   payload->compiler = compiler;
+  payload->env = env;
 }
 
 
