@@ -1,6 +1,6 @@
 /* pk-cmd-ios.c - Commands for operating on IO spaces.  */
 
-/* Copyright (C) 2019, 2020, 2021, 2022 Jose E. Marchesi */
+/* Copyright (C) 2019, 2020, 2021, 2022, 2023 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -88,7 +88,7 @@ pk_cmd_sub (int argc, struct pk_cmd_arg argv[], uint64_t uflags)
   name = PK_CMD_ARG_STR (argv[4]);
 
   /* Build the handler.  */
-  if (asprintf (&handler, "sub://%d/0x%" PRIx64 "/0x%lx/%s",
+  if (asprintf (&handler, "sub://%d/0x%" PRIx64 "/0x%" PRIx64 "/%s",
                 ios, base, size, name) == -1)
     return 0;
 
@@ -122,7 +122,7 @@ pk_cmd_proc (int argc, struct pk_cmd_arg argv[], uint64_t uflags)
   pid = PK_CMD_ARG_INT (argv[1]);
 
   /* Build the handler for the proc IOS.  */
-  if (asprintf (&handler, "pid://%ld", pid) == -1)
+  if (asprintf (&handler, "pid://%" PRIi64, pid) == -1)
     return 0;
 
   /* Open the IOS.  */
@@ -135,7 +135,7 @@ pk_cmd_proc (int argc, struct pk_cmd_arg argv[], uint64_t uflags)
     }
   free (handler);
 
-  /* Allright, now open sub spaces for the process' maps, if
+  /* All right, now open sub spaces for the process' maps, if
      requested.  */
   if (uflags & PK_PROC_F_MAPS || uflags & PK_PROC_F_MAPS_ALL)
     pk_open_proc_maps (ios_id, pid, uflags & PK_PROC_F_MAPS_ALL);
@@ -452,10 +452,29 @@ pk_cmd_mem (int argc, struct pk_cmd_arg argv[], uint64_t uflags)
 
   /* Create a new memory IO space.  */
   const char *arg_str = PK_CMD_ARG_STR (argv[1]);
-  char *mem_name;
+  char *mem_name = NULL;
 
-  if (asprintf (&mem_name, "*%s*", arg_str) == -1)
-    pk_fatal (_("out of memory"));
+  /* If the user didnt' specify a name for the memory IOS, search for
+     the first available *N*.  */
+  if (*arg_str == '\0')
+    {
+      int i;
+
+      for (i = 0; i < 99; ++i)
+        {
+          free (mem_name);
+          if (asprintf (&mem_name, "*%d*", i) == -1)
+            pk_fatal (_("out of memory"));
+
+          if (pk_ios_search (poke_compiler, mem_name) == NULL)
+            break;
+        }
+    }
+  else
+    {
+      if (asprintf (&mem_name, "*%s*", arg_str) == -1)
+        pk_fatal (_("out of memory"));
+    }
 
   if (pk_ios_search (poke_compiler, mem_name) != NULL)
     {
