@@ -25,7 +25,6 @@
 #include <errno.h>
 #include <limits.h>
 #include <fcntl.h>
-#include <assert.h>
 #include <glob.h> /* For tilde-expansion.  */
 #include <xalloc.h>
 #include <xstrndup.h>
@@ -496,7 +495,7 @@ pk_cmd_exec_1 (const char *str, struct pk_trie *cmds_trie, char *prefix)
                   }
                 default:
                   /* This should NOT happen.  */
-                  assert (0);
+                  PK_UNREACHABLE ();
                 }
 
               if (match)
