@@ -38,6 +38,7 @@
 #include "pk-utils.h"
 #include "pk-map.h"
 #include "pk-ios.h"
+#include "configmake.h"
 
 /* poke can be run either interactively (from a tty) or in batch mode.
    The following predicate records this.  */
@@ -801,7 +802,7 @@ poke_handle_exception (pk_val exception)
   assert (handler != PK_NULL);
   if (pk_call (poke_compiler, handler, NULL, NULL, 1, exception)
       == PK_ERROR)
-    assert (0);
+    PK_UNREACHABLE ();
 }
 
 void
